@@ -1,45 +1,10 @@
 import typing as tp
 
 from .qt import QT_VERSION
-if QT_VERSION == "PyQt5":
-    from PyQt5.QtCore import QTimer
-    from PyQt5 import QtWidgets
+if QT_VERSION == "PyQt6" and not tp.TYPE_CHECKING:
+    from PyQt6 import QtWidgets
 else:
-    from PySide2.QtCore import QTimer
-    from PySide2 import QtWidgets
-
-
-class Timer(object):
-    """A Timer for calling a function periodically.
-
-    The function passed in the constructor will be called
-    every time_in_ms milliseconds after the Timer is started,
-    until the Timer is stopped.
-
-    Args:
-        function: the function that will be called periodically
-    """
-
-    def __init__(self, function: tp.Callable[[], tp.Any]):
-        self._timer = QTimer()
-        self._timer.timeout.connect(function)
-        self._started = False
-
-    def start(self, time_in_ms: int):
-        """Starts the timer.
-
-        Args:
-            time_in_ms: time interval for calling the function.
-        """
-        if not self._started:
-            self._timer.start(time_in_ms)
-        self._started = True
-
-    def stop(self):
-        """Stops the timer."""
-        if self._started:
-            self._timer.stop()
-            self._started = False
+    from PySide6 import QtWidgets
 
 
 def alert(message: tp.Text, choices: tp.Optional[tp.Sequence[tp.Text]] = None) -> tp.Optional[int]:
@@ -77,20 +42,21 @@ def file_dialog(caption: tp.Text = "",
     Args:
         caption: the file dialog's caption
         directory: starting directory for the file dialog
-        file_filter: Sequence of allowed file extensions
-            For example:
+        file_filter:
+            Sequence of allowed file extensions. For example::
+
                 "*.cpp *.cc *.C *.c++"
                 "C++ files (*.cpp *.cc *.C *.c++)"
+
             are both valid ways of specifying a file filter.
     Returns:
         Path of chosen file
     """
     dialog = QtWidgets.QFileDialog(None, caption, directory)
-    dialog.setFileMode(QtWidgets.QFileDialog.AnyFile)
-    dialog.setFileMode(QtWidgets.QFileDialog.AnyFile)
+    dialog.setFileMode(QtWidgets.QFileDialog.FileMode.AnyFile)
     if file_filter is not None:
         dialog.setNameFilters(file_filter)
-    if dialog.exec() == QtWidgets.QDialog.Accepted:
+    if dialog.exec() == QtWidgets.QDialog.DialogCode.Accepted:
         return dialog.selectedFiles()[0]
     return None
 
@@ -98,8 +64,8 @@ def file_dialog(caption: tp.Text = "",
 def set_trace():
     '''Set a tracepoint in the Python debugger that works with Qt'''
     import pdb
-    if QT_VERSION == "PyQt5":
-        from PyQt5.QtCore import pyqtRemoveInputHook, pyqtRestoreInputHook
+    if QT_VERSION == "PyQt6":
+        from PyQt6.QtCore import pyqtRemoveInputHook
         pyqtRemoveInputHook()
     pdb.set_trace()
     # # set up the debugger
